
/* 
 * FILE:
 * dui-initdb.h
 *
 * FUNCTION:
 * Open up connection to the database. 
 *
 * HISTORY:
 * created by Linas Vepstas  March 2002
 */


#ifndef DUI_INITDB_H
#define DUI_INITDB_H


typedef struct DuiDBConnection_s DuiDBConnection;
typedef struct DuiDBRecordSet_s  DuiDBRecordSet;


/* provider must be "odbc" */
DuiDBConnection * dui_connection_new (const char * provider,
                                      const char * dbname, 
                                      const char * username);

void dui_connection_free (DuiDBConnection *conn);

/* issue a query on this connection.  FYI -- the query is actually performed
 * asynchronously; the 'ecord set may not yet contain valid data when this 
 * routine returns. */
DuiDBRecordSet * dui_connection_exec (DuiDBConnection *, const char * buff);

/* release the record set when one is done with it */
void dui_recordset_free (DuiDBRecordSet *);

/* prep a row.  Basically, this gets the 'next' row out of the database.
 * subsequent field fetches are for this row. Returns zero if there are no more rows
 */
int dui_recordset_fetch_row (DuiDBRecordSet *rs);

/* get the field value by name.  This is a little different/easier than the usual
 * trick of getting it by column number.
 */
const char * dui_recordset_get_value (DuiDBRecordSet *, const char * fieldname);


#endif /* DUI_INITDB_H */
 
