/*
 * FILE:
 * report.h
 *
 * FUNCTION:
 * Fill in widget values based on results of database query
 *
 * HISTORY:
 * Linas Vepstas March 2002
 */

#ifndef DUI_REPORT_H
#define DUI_REPORT_H

#include "window.h"
#include "dui-initdb.h"

DuiReport * dui_report_new (DuiWindow *);
void dui_report_destroy (DuiReport *);

/* set the row iterator widget.  This widget must
 * somehow be capable of reporting multiple rows
 * (ie. must have a way of creating a new row)
 * The widgetname must be in the scope of the gladefile:root_widget tree
 */
void dui_report_set_row_widget (DuiReport *, const char *widgetname);

/* widget must not be null. Either field or value must not be null.
 * If field is not null, it must be a valid database field.
 * Otherwise the constant value is used.
 */
void dui_report_add_column (DuiReport *dsp, 
                            const char *widget_name, int column_num,
                            const char * field, const char * key,
                            const char * value);


void dui_report_do_realize (DuiReport *);
const char * dui_report_get_name (DuiReport *);

/* pull data off the indicated connection and display it */
void dui_report_show_data (DuiReport *, DuiDBRecordSet *);

/* set the most recent action that generated data for this window.
 * If this window need to be refreshed, then this action will be
 * used to refresh it 
 */
void dui_report_set_last_action (DuiReport *, DuiAction *);

void dui_report_refresh (DuiReport *);

#endif /* DUI_REPORT_H */
